==> haskell-fsnotify0.3-0.3.0.1-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-F1LhetfLObEBH9llUstMn4
key:                  fsnotify-0.3.0.1-F1LhetfLObEBH9llUstMn4
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  b73cdef3d23aa40baa6c7abd8ec8a1bf
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-F1LhetfLObEBH9llUstMn4
depends:
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-4hNrn8A2j8DFnjk10ec1fH
    shelly-1.10.0.1-GW1gnmkKqlv4N3wLkDDZ5u text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.3-9Tj09IRjFnyE6cgV0AVkT

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify0.3-0.3.0.1-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-EOI36DmLsKWGqN1Knfjhbm
key:                  fsnotify-0.3.0.1-EOI36DmLsKWGqN1Knfjhbm
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  ec8f70fb72664e264bc200127e435bab
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-EOI36DmLsKWGqN1Knfjhbm
depends:
    async-2.2.5-KSZIoACaSMlHctQ7vOTAKz base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-ImPfXKsnEFoWojF8gY08O
    shelly-1.10.0.1-ISsPe2S82rLB8pfqKF0fXA text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.3-7hkgNf7Xk8N43CTrctBpCt

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
